@@ -9,7 +9,7 @@ def config():
     class Config:
         DB_HOST = "localhost"
         DB_PORT = "5432"
-        DB_TEST = "xli"
+        DB_TEST = "windyquery-test"
         DB_USER = "xli"
         DB_PASS = "xliadmin"
     yield Config
